==> claws-mail-4.0.0p0-ldap.tgz: include/claws-mail/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Jonathan Boeing <jonathan@claws-mail.org>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Darko Koruga <darko@users.sf.net>",
"Thorsten Maerz <thorsten@claws-mail.org>",
"Paul Mangan <paul@claws-mail.org>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Hoà Viêt Dinh",
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Andrej Kacian",
"Werner Koch",
"Charles Lehner",
"Colin Leroy-Mira",
"Paweł Pękala",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[ca] David Medina <opensusecatala@gmail.com>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[da] Erik P. Olsen <epodata@gmail.com>",
"[de] Simon Legner <simon.legner@gmail.com>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id_ID] MSulchan Darmawan <bleketux@gmail.com>",
"[it] Luigi Votta <luigi.vtt@gmail.com>",
"[ja] UTUMI Hirosi <utuhiro78@yahoo.co.jp>",
"[nb] Petter Adsen <petter@synth.no>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pl] Jakub Jankiewicz <jcubic@jcubic.pl>",
"[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
"[pt_PT] Pedro Albuquerque <palbuquerque73@gmail.com>",
"[ro] Cristian Secară <liste@secarica.ro>",
"[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
"[tr] Numan Demirdöğen <if.gnu.linux@gmail.com>",
"[zh_TW] Mark Chang <mark.cyj@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urošević <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"André Filipe de Assunção e Brito",
"Sergei Astanin",
"Ruslan N. Balkin",
"Andy Balaam",
"Henri Bauer",
"Didier Barvaux",
"Fabio Júnior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Blatinox",
"Hanno Böck",
"Pavlo Bohmat",
"Ralf Bormann",
"H. Merijn Brand",
"Eugene Brevdo",
"Olivier Brunel",
"Sean Buckheister",
"Anton Butanaev",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Natanael Copa",
"Jonathan Corbet",
"Christian Cornelssen",
"Palmer Dabbelt",
"George Danchev",
"Robert David",
"Kevin Day",
"Matthieu Dazy",
"Ben Deering",
"Jean Delvare",
"Pierric Descamps",
"Orivej Desh",
"Rodrigo Dias Arruda Senra",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Tiago Faria",
"Alessandro Di Federico",
"Lars Persson Fink",
"Bob Forsman",
"Matthias Förste",
"Ivan Francolin Martinez",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Michael Gmelin",
"Thierry Godefroy",
"Alex Gorbachenko",
"Michał Górny",
"Bodo Graumann",
"Yang Guilong",
"Ashish Gupta",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Alexander Lyons Harkness",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Olaf Hering",
"Christian Hesse",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Richard Hughes",
"Arthur Huillet",
"Ben Hutchings",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Daniel Jakots",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"kazken3",
"WAKAI Kazunao",
"Fabian Keil",
"Jakub Kiciński",
"Martin Kluge",
"IWAMOTO Kouichi",
"Mikhail Kurinnoi",
"Abhay S. Kushwaha",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Flavio Leitner",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Igor Mammedov",
"Tim Mann",
"Darac Marjal",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Raphael Michel",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Gustavo Noronha Silva",
"Ales Nosek",
"Emilian Nowak",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Miquel Oliete",
"Paul Ollis",
"Fredrik Olofssen",
"Orbea",
"Thomas Orgis",
"Reza Pakdel",
"Richard Palo",
"Alvar Penning",
"Damian Poddebniak",
"Marcel Pol",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Steve Randall",
"Jens Rantil",
"Ravemax",
"Eric S. Raymond",
"Ivan Rayner",
"David Relson",
"Volker Ribbert",
"Chad Robinson",
"Paul Rolland",
"Andreas Rönnquist",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Peter Sarvas",
"Oliver Schneider",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Michael Schwendt",
"Ralph Sennhauser",
"Setoh",
"Michael Shell",
"shigeri",
"Jesse Skinner",
"Ville Skyttä",
"Alex Smith",
"Dale P. Smith",
"Avinash Sonawane",
"Andrea Spadaccini",
"Manuel Stoeckl",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Timo Teräs",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Ramin Yaghoubzadeh Torky",
"Anders Troback",
"Tsutsui",
"Aleksandar Urošević",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Michael Vilain",
"Johan Vromans",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Florian Weimer",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"YUP",
"Daniel Zaoui",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};

==> claws-mail-4.2.0-ldap.tgz: include/claws-mail/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Jonathan Boeing <jonathan@claws-mail.org>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Thorsten Maerz <thorsten@claws-mail.org>",
"Paul Mangan <paul@claws-mail.org>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Holger Berndt",
"Hoà Viêt Dinh",
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Andrej Kacian",
"Werner Koch",
"Darko Koruga",
"Charles Lehner",
"Colin Leroy-Mira",
"Paweł Pękala",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[ca] David Medina <opensusecatala@gmail.com>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[da] Erik P. Olsen <epodata@gmail.com>",
"[de] Simon Legner",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id_ID] MSulchan Darmawan <bleketux@gmail.com>",
"[it] Luigi Votta <luigi.vtt@gmail.com>",
"[ja] UTUMI Hirosi <utuhiro78@yahoo.co.jp>",
"[nb] Petter Adsen <petter@synth.no>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pl] Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>",
"[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
"[pt_PT] Hugo Carvalho <hugokarvalho@hotmail.com>",
"[ro] Cristian Secară <liste@secarica.ro>",
"[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
"[tr] Numan Demirdöğen <if.gnu.linux@gmail.com>",
"[zh_TW] Mark Chang <mark.cyj@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Paul Mangan <paul@claws-mail.org>",
"[de] Christoph Klassen <christoph.klassen@intevation.de>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urošević <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"André Filipe de Assunção e Brito",
"Sergei Astanin",
"Ruslan N. Balkin",
"Andy Balaam",
"Henri Bauer",
"Didier Barvaux",
"Fabio Júnior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Blatinox",
"Hanno Böck",
"Pavlo Bohmat",
"Ralf Bormann",
"H. Merijn Brand",
"Eugene Brevdo",
"Olivier Brunel",
"Sean Buckheister",
"Anton Butanaev",
"Henrik Carlqvist",
"Luca Cavalli",
"Gianni Ceccarelli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Natanael Copa",
"Jonathan Corbet",
"Christian Cornelssen",
"Palmer Dabbelt",
"George Danchev",
"Robert David",
"Kevin Day",
"Matthieu Dazy",
"Ben Deering",
"Jean Delvare",
"Pierric Descamps",
"Orivej Desh",
"Rodrigo Dias Arruda Senra",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Tiago Faria",
"Alessandro Di Federico",
"Lars Persson Fink",
"David Fletcher",
"Bob Forsman",
"Matthias Förste",
"Ivan Francolin Martinez",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Michael Gmelin",
"Thierry Godefroy",
"Alex Gorbachenko",
"Michał Górny",
"Bodo Graumann",
"Yang Guilong",
"Ashish Gupta",
"Daniel Gustafson",
"Roland Haas",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Alexander Lyons Harkness",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Olaf Hering",
"Christian Hesse",
"Higuchi",
"Hiramatu",
"HIROSHIMA",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Charles Huber",
"Michael Hughes",
"Richard Hughes",
"Arthur Huillet",
"Ben Hutchings",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Daniel Jakots",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"kazken3",
"WAKAI Kazunao",
"Fabian Keil",
"Jakub Kiciński",
"Martin Kluge",
"IWAMOTO Kouichi",
"Mikhail Kurinnoi",
"Abhay S. Kushwaha",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Flavio Leitner",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Igor Mammedov",
"Tim Mann",
"Darac Marjal",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Raphael Michel",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"Frank Mueller",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Gustavo Noronha Silva",
"Ales Nosek",
"Emilian Nowak",
"James Noyes",
"nycex",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Miquel Oliete",
"Paul Ollis",
"Fredrik Olofssen",
"Orbea",
"Thomas Orgis",
"Reza Pakdel",
"Richard Palo",
"Alvar Penning",
"Damian Poddebniak",
"Marcel Pol",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Steve Randall",
"Jens Rantil",
"Ravemax",
"Eric S. Raymond",
"Ivan Rayner",
"David Relson",
"Volker Ribbert",
"Chad Robinson",
"Paul Rolland",
"Andreas Rönnquist",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Peter Sarvas",
"Oliver Schneider",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Michael Schwendt",
"Ralph Sennhauser",
"Setoh",
"Michael Shell",
"shigeri",
"Jesse Skinner",
"Ville Skyttä",
"Alex Smith",
"Dale P. Smith",
"Avinash Sonawane",
"Andrea Spadaccini",
"Manuel Stoeckl",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Sakaguchi Takayuki",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Timo Teräs",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Ramin Yaghoubzadeh Torky",
"Anders Troback",
"Tsutsui",
"Aleksandar Urošević",
"Petr Vanek",
"Jeroen Versteeg",
"Viatrix",
"Kevin Vigor",
"Michael Vilain",
"Johan Vromans",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Florian Weimer",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"YUP",
"Daniel Zaoui",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};
